Facet<Input, Output> class
A typed extension point that collects values from multiple providers and reduces them with a combine function.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
of(
Input value) → FacetExtension< Input, Output> -
Create an extension that provides
valueto this facet. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited