HistoryEntry class

A single undo/redo entry: an inverse ChangeSet and the EditorSelection to restore when this entry is applied.

Constructors

HistoryEntry(ChangeSet changes, EditorSelection selection)
const

Properties

changes ChangeSet
The inverse changeset that, when applied, reverts the corresponding edit.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selection EditorSelection
The selection to restore after applying changes.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited