TreeBuffer class

Compact flat representation for leaf/simple nodes. Buffer: typeId, from, to, endIndex per node.

Constructors

TreeBuffer(List<int> buffer, int length, NodeSet set)
const

Properties

buffer List<int>
final
hashCode int
The hash code for this object.
no setterinherited
length int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
set NodeSet
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited