Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
detectRegions(
Document doc) → List< FoldRegion> -
Returns all foldable regions in
docbased on indentation. -
regionAtLine(
Document doc, int lineNumber) → FoldRegion? -
Returns the FoldRegion whose FoldRegion.startLine equals
lineNumber, or null if no such region exists.